==> ovirt-engine-sdk-java-4.2.3.tar.gz: ovirt-engine-sdk-java-4.2.3/target/generated-sources/org/ovirt/engine/sdk4/services/DiskSnapshotsService.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.services;

import java.io.IOException;
import java.math.BigInteger;
import java.util.List;
import org.ovirt.engine.sdk4.Request;
import org.ovirt.engine.sdk4.Response;
import org.ovirt.engine.sdk4.Service;
import org.ovirt.engine.sdk4.types.DiskSnapshot;

/**
 * Manages the collection of disk snapshots available in an storage domain.
 */
public interface DiskSnapshotsService extends Service {
    /**
     * Returns the list of disk snapshots of the storage domain.
     * 
     * The order of the returned list of disk snapshots isn't guaranteed.
     */
    public interface ListRequest extends Request<ListRequest, ListResponse> {
        /**
         * Indicates which inner links should be _followed_. The objects referenced by these links will be fetched as part
         * of the current request. See <<documents/003_common_concepts/follow, here>> for details.
         */
        ListRequest follow(String follow);
        /**
         * Sets the maximum number of snapshots to return. If not specified all the snapshots are returned.
         */
        ListRequest max(Integer max);
        /**
         * Sets the maximum number of snapshots to return. If not specified all the snapshots are returned.
         */
        ListRequest max(Long max);
        /**
         * Sets the maximum number of snapshots to return. If not specified all the snapshots are returned.
         */
        ListRequest max(BigInteger max);
    }
    
    /**
     * Returns the list of disk snapshots of the storage domain.
     * 
     * The order of the returned list of disk snapshots isn't guaranteed.
     */
    public interface ListResponse extends Response {
        List<DiskSnapshot> snapshots();
    }
    
    /**
     * Returns the list of disk snapshots of the storage domain.
     * 
     * The order of the returned list of disk snapshots isn't guaranteed.
     */
    ListRequest list();
    
    DiskSnapshotService snapshotService(String id);
    /**
     * Service locator method, returns individual service on which the URI is dispatched.
     */
    Service service(String path);
}

==> ovirt-engine-sdk-java-4.4.5.tar.gz: ovirt-engine-sdk-java-4.4.5/target/generated-sources/org/ovirt/engine/sdk4/services/DiskSnapshotsService.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.services;

import java.io.IOException;
import java.math.BigInteger;
import java.util.List;
import org.ovirt.engine.sdk4.Request;
import org.ovirt.engine.sdk4.Response;
import org.ovirt.engine.sdk4.Service;
import org.ovirt.engine.sdk4.types.DiskSnapshot;

/**
 * Manages the collection of disk snapshots available in an storage domain.
 */
public interface DiskSnapshotsService extends Service {
    /**
     * Returns the list of disk snapshots of the storage domain.
     * 
     * The order of the returned list of disk snapshots isn't guaranteed.
     */
    public interface ListRequest extends Request<ListRequest, ListResponse> {
        /**
         * Indicates which inner links should be _followed_. The objects referenced by these links will be fetched as part
         * of the current request. See <<documents/003_common_concepts/follow, here>> for details.
         */
        ListRequest follow(String follow);
        /**
         * If true return also active snapshots. If not specified active snapshots are not returned.
         */
        ListRequest includeActive(Boolean includeActive);
        /**
         * Sets the maximum number of snapshots to return. If not specified all the snapshots are returned.
         */
        ListRequest max(Integer max);
        /**
         * Sets the maximum number of snapshots to return. If not specified all the snapshots are returned.
         */
        ListRequest max(Long max);
        /**
         * Sets the maximum number of snapshots to return. If not specified all the snapshots are returned.
         */
        ListRequest max(BigInteger max);
    }
    
    /**
     * Returns the list of disk snapshots of the storage domain.
     * 
     * The order of the returned list of disk snapshots isn't guaranteed.
     */
    public interface ListResponse extends Response {
        List<DiskSnapshot> snapshots();
    }
    
    /**
     * Returns the list of disk snapshots of the storage domain.
     * 
     * The order of the returned list of disk snapshots isn't guaranteed.
     */
    ListRequest list();
    
    DiskSnapshotService snapshotService(String id);
    /**
     * Service locator method, returns individual service on which the URI is dispatched.
     */
    Service service(String path);
}
